@@ -14,6 +14,7 @@ use {
         },
         skin::SkinEntry,
         syntactic::SyntaxTheme,
+        verb::ExecPattern,
     },
     ahash::AHashMap,
     crokey::crossterm::style::Attribute,
@@ -107,6 +108,12 @@ pub struct Conf {
 
     #[serde(alias="content-search-max-file-size", deserialize_with="file_size::deserialize", default)]
     pub content_search_max_file_size: Option<u64>,
+
+    #[serde(alias="terminal-title")]
+    pub terminal_title: Option<ExecPattern>,
+
+    // BEWARE: entries added here won't be usable unless also
+    // added in read_file!
 }
 
 impl Conf {
@@ -187,6 +194,7 @@ impl Conf {
         overwrite!(self, max_staged_count, conf);
         overwrite!(self, show_matching_characters_on_path_searches, conf);
         overwrite!(self, content_search_max_file_size, conf);
+        overwrite!(self, terminal_title, conf);
         self.verbs.append(&mut conf.verbs);
         // the following maps are "additive": we can add entries from several
         // config files and they still make sense
